@@ -11,10 +11,8 @@ for my $field ("Git", "Browser") {
     $data->{"Vcs-$field"} = $tmp;
 }
 
-open (FID, "< debian/compat");
-$data->{Compat} = join ("", <FID>);
-chomp $data->{Compat};
-close FID;
+$data -> {"Build-Depends"} =~ m{debhelper-compat \(= ([0-9]+)\)};
+$data->{Compat} = $1;
 
 open (FID, "< debian/changelog");
 while (<FID>) {
